Polynomials
-----------

See also :func:`~mpmath.taylor` and :func:`~mpmath.chebyfit` for
approximation of functions by polynomials.

Polynomial evaluation (``polyval``)
...................................

.. autofunction:: mpmath.polyval

Polynomial roots (``polyroots``)
................................

.. autofunction:: mpmath.polyroots
